P2PKH class

Constructors

P2PKH({required PaymentData data, dynamic network})

Properties

addressInBlake2b String
no setter
bech32Address String
no setter
data PaymentData
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
network NetworkType
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tapRootAddress String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getTaprootAddress(Uint8List publicKey, String prefix) String
getTaprootOutputKey(Uint8List publicKey) List<int>
The tweaked 32-byte x-only output key committed to by a P2TR address for publicKey — i.e. the key a BIP340 key-path signature actually verifies against, not the untweaked internal public key.