PSBT class

Represents a PSBT(BIP-0174).

Constructors

PSBT.fromTransferPsbt(BtcTransferInfo btcInfo, {WalletType walletType = WalletType.SingleSignatureWallet})
factory
PSBT.parse(String psbtBase64)
Parse a PSBT from a base64 string.
factory

Properties

fee int
Get the fee of the transaction.
no setter
hashCode int
The hash code for this object.
no setterinherited
inputAddresses List<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendingAmount int
Get the sending amount of the transaction.
no setter
transferAmount int
no setter
unsignedTransaction ↔ Transaction?
Get transaction not signed yet.
getter/setter pair

Methods

addSignature(int inputIndex, String signature, String publicKey) → void
Add a signature to the PSBT.
estimateFee(int feeRate, BtcAddressType addressType) int
Get estimated fee for the transaction.
getInputAddresses({bool isTestnet = false, String chain = 'btc'}) List<String>
getSignedTransaction(BtcAddressType addressType) → Transaction
Get the transaction if all inputs are signed.
getTransferAmount({bool isTestnet = false, String chain = 'btc'}) int
Get the transfer amount of the transaction.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
Generate the PSBT to base64 string.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

psbtToBytes(String psbtBase64) Uint8List
psbtToGlobalMap(Uint8List psbtBytes, int offset) Map<String, String>