AddressLookupTableState class

Address Lookup Table State

Constructors

AddressLookupTableState({int typeIndex = 1, required BigInt deactivationSlot, required BigInt lastExtendedSlot, required int lastExtendedSlotStartIndex, required Pubkey? authority, required List<Pubkey> addresses})
const

Properties

addresses List<Pubkey>
final
authority Pubkey?
final
deactivationSlot BigInt
final
hashCode int
The hash code for this object.
no setterinherited
lastExtendedSlot BigInt
final
lastExtendedSlotStartIndex int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeIndex int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited