getString method

String getString(
  1. BufferEncoding encoding, [
  2. int offset = 0,
  3. int? length
])

Reads a region of the buffer as an encoded string.

Items are read from the range [offset : offset+length]. If length is omitted, the range extends to the end of the buffer.

The range must satisfy the relations 0offsetoffset+lengththis.length.

Implementation

String getString(final BufferEncoding encoding, [final int offset = 0, final int? length]) {
  final int end = length != null ? offset + length : this.length;
  final Iterable<int> bytes = _data.getRange(offset, end);
  return _encode(Uint8List.fromList(bytes.toList(growable: false)), encoding);
}