setAll method

void setAll(
  1. int offset,
  2. Iterable<int> bytes
)

Writes a byte array to a region of the buffer starting at offset.

If offset + bytes length exceeds length, the range extends to the end of the buffer.

The offset must satisfy the relations 0offsetthis.length.

Implementation

void setAll(
  final int offset,
  final Iterable<int> bytes,
) {
  _data.setAll(offset, bytes);
}