setBigInt method
Writes a big signed integer to a region of the buffer.
The value is written to the range [offset : offset+length]. If length is omitted, the
minimum number of bytes required to store this big integer value is used.
The range must satisfy the relations 0 ≤ offset ≤ offset+length ≤ this.length.
Returns the position of the last element written to the buffer ([offset]+[length]).
Implementation
int setBigInt(
final BigInt value,
final int offset, [
final int? length,
final Endian endian = Endian.little,
]) {
return _setBytes(_toBytesBigInt(value, length), offset, endian);
}