BufferReader class

Buffer Reader

Inheritance

Constructors

BufferReader(Buffer buffer)
Creates a view over buffer that maintains its offset position while reading data from the buffer.
BufferReader.fromList(Iterable<int> bytes)
Creates a BufferReader from a list of bytes.
BufferReader.fromUint8List(Uint8List bytes)
Creates a BufferReader from a Uint8List

Properties

buffer Buffer
The buffer to traverse.
final
first int
The first element.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether this collection has no elements.
no setteroverride
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
iterator Iterator<int>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last int
The last element.
no setterinherited
length int
The number of elements in this Iterable.
no setteroverride
offset int
The current offset.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single int
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

advance(int steps) → void
Advance the current offset position by steps.
any(bool test(int element)) bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) int
Returns the indexth element.
inherited
every(bool test(int element)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(int element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(int element), {int orElse()?}) int
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, int element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<int> other) Iterable<int>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(int element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
getBigInt(int length) BigInt
getBigUint(int length) BigInt
getBool() bool
getBuffer([int? length]) Buffer
Creates a new Buffer from a region of buffer and advances the internal offset by length.
getDateTime() DateTime
getFloat32() double
getFloat64() double
getInt(int length) int
getInt128() BigInt
getInt16() int
getInt32() int
getInt64() int
getInt8() int
getString(int length, [BufferEncoding encoding = BufferEncoding.utf8]) String
getUint(int length) int
getUint128() BigInt
getUint16() int
getUint32() int
getUint64() BigInt
getUint8() int
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(int element), {int orElse()?}) int
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(int e)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(int combine(int value, int element)) int
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(int element), {int orElse()?}) int
The single element that satisfies test.
inherited
skip(int count) Iterable<int>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(int value)) Iterable<int>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) Iterable<int>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(int value)) Iterable<int>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toBuffer({required bool slice}) Buffer
If slice == true the returned buffer is resized to include only the remaining items.
toList({bool growable = true}) List<int>
Creates a List containing the elements of this Iterable.
inherited
toSet() Set<int>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
Returns a string representation of (some of) the elements of this.
override
where(bool test(int element)) Iterable<int>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) int
Returns the byte at index.