BufferWriter constructor

BufferWriter(
  1. int length, {
  2. bool growable = false,
})

Creates a zero initialized buffer of size length that maintains its offset position while writing data to the buffer.

Implementation

BufferWriter(
  final int length, {
  this.growable = false,
}): buffer = Buffer(length);