numRequiredSignatures property
The total number of signatures required to make the transaction valid. The signatures must
match the first numRequiredSignatures of Message.accountKeys.
Implementation
final int numRequiredSignatures;
The total number of signatures required to make the transaction valid. The signatures must
match the first numRequiredSignatures of Message.accountKeys.
final int numRequiredSignatures;