MessageInstruction class

Message Instruction

Constructors

MessageInstruction({required int programIdIndex, required Iterable<int> accounts, required String data})
An instruction to execute by a program.
const

Properties

accounts Iterable<int>
List of ordered indices into the message.accountKeys array indicating which accounts to pass to the program.
final
data String
The program's input data encoded as a base-58 string.
final
hashCode int
The hash code for this object.
no setterinherited
programIdIndex int
Index into the Message.accountKeys array indicating the program account that executes this instruction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited