NaClDetached class

NaCl Detached

Constructors

NaClDetached()
NaCl sign.detached methods.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sync(Uint8List message, Uint8List seckey) Uint8List
Signs message using the seckey and returns the signature.
toString() String
A string representation of this object.
inherited
verifySync(Uint8List message, Uint8List signature, Uint8List pubkey) bool
Returns true if the signature was derived by signing the message using pubkey's secret key.

Operators

operator ==(Object other) bool
The equality operator.
inherited