NaClKeypair class

NaCl Keypair

Constructors

NaClKeypair()
NaCl sign.keypair methods.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromSeckeySync(Uint8List seckey) Ed25519Keypair
Creates a keypair from a seckey byte array.
fromSeedSync(Uint8List seed) Ed25519Keypair
Creates a keypair from a 32-byte seed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sync() Ed25519Keypair
Generates a random keypair.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited