Program class abstract

Program

Constructors

Program(Pubkey pubkey)
Solana program.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pubkey Pubkey
The public key that identifies this program (i.e. program id).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createTransactionIntruction(Enum instruction, {required List<AccountMeta> keys, List<Iterable<int>> data = const []}) TransactionInstruction
Creates a TransactionInstruction for the program instruction.
encodeInstruction<T extends Enum>(T instruction) Iterable<int>
Encodes the program instruction.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited