ScTransactionBuilder class

Assembles an SC transaction through the WASM pipeline.

The default factory ScTransactionBuilder.create auto-loads sc.wasm from the package bundle and uses ScWasmRunBridge under the hood.

final txData = await ScTransactionBuilder.create().build(unsignedTx);

Constructors

ScTransactionBuilder({required ScWasmBridge wasmBridge})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wasmBridge ScWasmBridge
final

Methods

build(ScUnsignedTransaction unsignedTx) Future<ScTxData>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() Future<ScTransactionBuilder>
Creates a builder with sc.wasm auto-loaded from the package bundle.