dispose method

void dispose()

Releases resources owned by a bridge created by this builder.

A builder constructed with the public constructor does not own its bridge, so disposing it cannot destroy a bridge shared by another builder.

Implementation

void dispose() {
  if (!_ownsBridge) return;
  if (wasmBridge case final ScWasmIsolateBridge bridge) {
    bridge.dispose();
  }
}