ScTxSigner class

Signs a ScTxData by producing Ed25519 signatures for each digest in ScTxData.toSign and writing them into the V2 transaction's satisfiedPolicy.signatures slots.

Inheritance

Constructors

ScTxSigner(WalletType wallet, ScTxData txData)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txData ScTxData
finalgetter/setter pairinherited-setteroverride-getter
wallet WalletType
finalinherited

Methods

checkTxData() bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
safeVerify() bool
inherited
sign() ScTxData
override
toString() String
A string representation of this object.
inherited
verify() bool
override

Operators

operator ==(Object other) bool
The equality operator.
inherited