ScWasmBridge class abstract

Bridge for calling the SC WASM module (sc.wasm).

The built-in ScWasmRunBridge uses package:wasm_run (wasmtime / wasmi). Web platforms can implement this with package:wasm_interop.

Implementers

Constructors

ScWasmBridge()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processUnsignedTransaction(ScUnsignedTransaction unsignedTx) Future<ScWasmResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited