ScWasmBridgeBase class abstract

Base ScWasmBridge that serializes the unsigned transaction to JSON and delegates the actual WASM call to processJson.

Implemented types
Implementers

Constructors

ScWasmBridgeBase()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processJson(String jsonString) Future<String>
Platform-specific: pass the unsigned transaction JSON, call the WASM module, and return the result JSON string.
processUnsignedTransaction(ScUnsignedTransaction unsignedTx) Future<ScWasmResult>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited