ScWasmLoader typedef

ScWasmLoader = Future<Uint8List> Function()

Loads the bundled SC WASM bytes.

Flutter callers can provide a custom loader backed by rootBundle when they need to override the package asset.

Implementation

typedef ScWasmLoader = Future<Uint8List> Function();