ScpSigHash class

Pure-Dart implementation of the SCP V2 signing digest (scpSigHash).

Translates the JS scpSigHash() function: concatenates canonically-encoded transaction fields and hashes with Blake2b-256.

Constructors

ScpSigHash()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

computeDigests(ScpUnsignedTransaction tx) List<String>
Compute signing digests for every transactionSignatures entry.