ScpTransactionSignature class
Constructors
- ScpTransactionSignature({required String parentID, int publicKeyIndex = 0, ScpCoveredFields? coveredFields, String signature = ''})
-
ScpTransactionSignature.fromJson(Map<
String, dynamic> json) -
factory
Properties
- coveredFields → ScpCoveredFields
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parentID → String
-
final
- publicKeyIndex → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited