BchCoin class

Create a bch wallet using mnemonic or private key, with a signature algorithm of EcdaSignature and an address type of bch Schnorr for bch not implemented

Inheritance

Constructors

BchCoin({dynamic setting})
BchCoin.fromPrivateKey(dynamic privateKey, [WalletSetting? setting])
factory

Properties

address String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mnemonic String?
privateKey and publicKey key are always Uint8List; mnemonic and address are always String
latefinalinherited
privateKey Uint8List
latefinalinherited
publicKey Uint8List
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setting WalletSetting
getter/setter pair
sighashType int
final

Methods

initFromMnemonic(String mnemonic) Future<void>
inherited
initFromPrivateKey(Uint8List privateKey) → void
inherited
mnemonicToAddress(String mnemonic) Future<String>
inherited
mnemonicToPrivateKey(String mnemonic) Future<Uint8List>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
privateKeyToPublicKey(Uint8List privateKey) Uint8List
override
publicKeyToAddress(Uint8List publicKey) String
override
sign(String message) String
override
signWithHashType(String message, int hashType) String
Sign with an explicit sighash type, keeping the digest's committed hashType consistent with the hashType byte embedded in the DER signature (GSPL callers compute both from the same value).
toString() String
A string representation of this object.
inherited
verify(String signature, String message) bool
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMnemonic(String mnemonic, [WalletSetting? setting]) Future<BchCoin>