BufferWriter constructor
Creates a zero initialized buffer of size length that maintains its offset position while writing data to the buffer.
Implementation
BufferWriter(
final int length, {
this.growable = false,
}): buffer = Buffer(length);