MessageHeader class
Message Header
Constructors
- MessageHeader({required int numRequiredSignatures, required int numReadonlySignedAccounts, required int numReadonlyUnsignedAccounts})
-
Details the account types and signatures required by the transaction (signed and read-only
accounts).
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- numReadonlySignedAccounts → int
-
The last
numReadonlySignedAccountsof the signed keys are read-only accounts.final - numReadonlyUnsignedAccounts → int
-
The last
numReadonlyUnsignedAccountsof the unsigned keys are read-only accounts.final - numRequiredSignatures → int
-
The total number of signatures required to make the transaction valid. The signatures must
match the first
numRequiredSignaturesof Message.accountKeys.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited