ScUnsignedTransaction class
Raw unsigned transaction input for the SC WASM module (sc.wasm).
Contains merkle proofs and raw addresses, before the WASM computes signing
digests via getUnsignedV2Transaction.
Constructors
-
ScUnsignedTransaction({List<
ScUnsignedSiacoinInput> siacoinInputs = const [], List<ScUnsignedSiacoinOutput> siacoinOutputs = const [], required String minerFee}) -
ScUnsignedTransaction.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minerFee → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
siacoinInputs
→ List<
ScUnsignedSiacoinInput> -
final
-
siacoinOutputs
→ List<
ScUnsignedSiacoinOutput> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited