ScWasmBridge class abstract
Bridge for computing SC transaction signing digests.
Two implementations coexist:
- ScWasmRunBridge (default): interprets the bundled
sc.wasmwithpackage:wasd, pure Dart and runs everywhere, but slower. - ScGoFfiBridge: calls a native library through
dart:ffi, much faster, but the caller must supply a library built for their platform.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processUnsignedTransaction(
ScUnsignedTransaction unsignedTx) → Future< ScWasmResult> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited