ScWasmRunBridge class

Inheritance

Constructors

ScWasmRunBridge(Uint8List _wasmBytes)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processJson(String jsonString) Future<String>
Implementation-specific: take the unsigned transaction JSON, compute the signing digests, and return the result transaction JSON string.
override
processUnsignedTransaction(ScUnsignedTransaction unsignedTx) Future<ScWasmResult>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited