ScpUnsignedTransaction class
Raw unsigned transaction input from the SCP API.
Constructors
-
ScpUnsignedTransaction({List<
ScpSiacoinInput> siacoinInputs = const [], List<ScpSiacoinOutput> siacoinOutputs = const [], List<String> minerFees = const [], List<ScpTransactionSignature> transactionSignatures = const [], List<String> arbitraryData = const []}) -
ScpUnsignedTransaction.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
arbitraryData
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
minerFees
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
siacoinInputs
→ List<
ScpSiacoinInput> -
final
-
siacoinOutputs
→ List<
ScpSiacoinOutput> -
final
-
transactionSignatures
→ List<
ScpTransactionSignature> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited